@@ -6,6 +6,7 @@ import {
   Options,
   Script,
   Program,
+  JsMinifyOptions,
 } from "./types";
 export * from "./types";
 import { BundleInput, compileBundleOptions } from "./spack";
@@ -29,39 +30,14 @@ export function plugins(ps: Plugin[]): Plugin {
 }
 
 export class Compiler {
-  // /**
-  //  * Parse source code as a babel ast.
-  //  * 
-  //  * If `options.transforms` is specified, this method also applies transforms.
-  //  * 
-  //  * @param src Source code
-  //  * @param options 
-  //  */
-  // babelify(input: string, options?: BabelifyOptions): Promise<babel.Program>;
-  // babelify(input: Program, options?: BabelifyOptions): Promise<babel.Program>;
-  // babelify(input: string | Program, options?: BabelifyOptions): Promise<babel.Program> {
-  //   const shouldParseInput = typeof input === 'string';
-  //   return bindings.babelify({
-  //     shouldParseInput,
-  //   }, input, options);
-  // }
 
-  // /**
-  //  * Parse source code as a babel ast.
-  //  * 
-  //  * If `options.transforms` is specified, this method also applies transforms.
-  //  * 
-  //  * @param src Source code
-  //  * @param options 
-  //  */
-  // babelifySync(input: string, options?: BabelifyOptions): babel.Program;
-  // babelifySync(input: Program, options?: BabelifyOptions): babel.Program;
-  // babelifySync(input: string | Program, options?: BabelifyOptions): babel.Program {
-  //   const shouldParseInput = typeof input === 'string';
-  //   return bindings.babelifySync({
-  //     shouldParseInput
-  //   }, input, options);
-  // }
+  async minify(src: string, opts?: JsMinifyOptions): Promise<Output> {
+    return bindings.minify(src, toBuffer(opts ?? {}));
+  }
+
+  minifySync(src: string, opts?: JsMinifyOptions): Output {
+    return bindings.minifySync(src, toBuffer(opts ?? {}));
+  }
 
   parse(
     src: string,
@@ -320,6 +296,14 @@ export function bundle(
   return compiler.bundle(options)
 }
 
+export async function minify(src: string, opts?: JsMinifyOptions): Promise<Output> {
+  return compiler.minify(src, opts);
+}
+
+export function minifySync(src: string, opts?: JsMinifyOptions): Output {
+  return compiler.minifySync(src, opts);
+}
+
 export const DEFAULT_EXTENSIONS = Object.freeze([
   ".js",
   ".jsx",
